@@ -17,31 +17,28 @@ library(DescTools)
 library(PBSmapping)
 library(R.utils)
 library(rgeos)
-library(yaml)
 
-#Probe shape definition as global variables (currently has a head/tip, a body/probe and a cable zone of avoidance (all should be in mm):
+#Probe shape definition as global variables (currently has a head/tip, a body/probe and a cable zone of avoidance (all should be in degrees):
 #plate_scale"/mm scaling
-#plate_scale <<- 15.008
-#! Added by Sam to use the same constants file as Ayoan's code uses
-hector_constants <<- read_yaml(paste(Sys.getenv('HECTOROBSPIPELINE_LOC'),"constants/HECTOR_CONSTANTS.yaml", sep='/'))
+plate_scale <<- 15.008
 
 #Field dimensions and parameters:
-fov <<- hector_constants$HECTOR_plate_radius*2  #diameter of the field in mm
-skybuffer<<-8 #clear-edge buffer
-wceg <<- 2.* 15  #Width of the cable exit gap (this is the 2*n where n=15mm initially in Julia's notes)
-ceg_pos <<- cbind(x=fov/2.*cosd(c(-90,30,150)),y=fov/2.*sind(c(-90,30,150)), deg=c(-90,30,150))
-E0<<-sqrt((wceg/2.)**2-(9)**2) #E is the line joining the solid ferule end to the centre of the exit point. 
+fov <<- 236*2 * plate_scale/3600 #2 degree field - a bit for sky fibres.
+wceg <<- 2.* 15 * plate_scale/3600 #Width of the cable exit gap (this is the 2*n where n=15mm initially in Julia's notes)
+ceg_pos <<- cbind(x=c(0,0.8504,-0.8504),y=c(-0.982,0.49098,0.49098), deg=c(-90,30,150))
+mid_ceg_pos<<-cbind(x=c(0,-0.8504,0.8504),y=c(0.982,-0.49098,-0.49098), deg= c(90,210,-30))
+E0<<-sqrt((wceg/2.)**2-(9*plate_scale/3600)**2) #E is the line joining the solid ferule end to the centre of the exit point. 
 #E0=SQRT((n^2)-81). If E<E0, then need to point to the next least contaminated exit. This step prevents a ferule from 
 #blocking an exit such that other cables will not get past.
-fbr <<- 45 #Fibre bend radius
+fbr <<- 45 * plate_scale/3600 #Fibre bend radius
 
 #Galaxy and standard star bundle dimensions:
-tip_w <<- 14.5/sqrt(2)  
-tip_l <<- 14.5/sqrt(2)   
-probe_w <<- 14.5 
-probe_l <<- 45 
-cable_w <<- 8.5 
-cable_l <<- 38 
+tip_w <<- 14.5/sqrt(2) * plate_scale/3600 #(instead of 12)
+tip_l <<- 14.5/sqrt(2) * plate_scale/3600  
+probe_w <<- 14.5 * plate_scale/3600 #(instead of 8.5)
+probe_l <<- 45 * plate_scale/3600
+cable_w <<- 8.5 * plate_scale/3600
+cable_l <<- 38 * plate_scale/3600
 excl_radius <<- sqrt(2.*((tip_w/2)^2))
 dngalprobes <<- 19
 nstdprobes <<- 2
@@ -52,21 +49,17 @@ nprobes <<- dngalprobes #Start with the number of galaxy targets. There will be
 
 #Guide bundle dimensions:
 #Julia: The guide bundles should be the same 14mm width but shorter than the hexabundle ferules by 20mm ~50mm total plus cable bit.
-gtip_w <<- 14.5/sqrt(2)
-gtip_l <<- 14.5/sqrt(2)
-gprobe_w <<- 14.5
-gprobe_l <<- 45
-gcable_w <<- 8.5
-gcable_l <<- 38
+gtip_w <<- 14.5/sqrt(2) * plate_scale/3600
+gtip_l <<- 14.5/sqrt(2) * plate_scale/3600
+gprobe_w <<- 14.5 * plate_scale/3600
+gprobe_l <<- 45 * plate_scale/3600 
+gcable_w <<- 8.5 * plate_scale/3600
+gcable_l <<- 38 * plate_scale/3600
 gexcl_radius <<- sqrt(2.*((gtip_w/2)^2))
 
 #Setting timeout time (in cpu seconds, I think) for how long each attempt lasts before moving on. 
 #The code will try for at most 15 times that before starting to swap a probe.
-#timeout<<-180 #180 seconds x 15 is about half an hour and is about right. Less than about 90 seconds led to problems in highly conflicted field..
-timeout<<-250 #Increased to account for longer conflict calculation time due to rounded heads so code still has enough time time try enough angles variations.
-
-#angle step going around the head to approximate circle as a polygon. The smaller angles are more precice but lead to longer configuration time.
-delta_poly<<-5 #5 degrees leads to a 0.1% radius buffer around the head and configuration seems to take a bit longer than a square head.
+timeout<<-180 #180 seconds x 15 is about half an hour and is about right. Less than about 90 seconds led to problems in highly conflicted field..
 
 #Compute the (horizontal/RA/x-axis) distance to the field edge.
 dist2fieldedge <- function(x,y){
@@ -196,6 +189,25 @@ adjust_angle <- function(theta,fgang){
   } else if (theta > fgang + 180){
     theta=theta-360
   }
+  
+  #fgang is the first_guess_ang.
+  #Upper left, should use a range that is between -180 and 180.
+  # if (fgang<0){
+  #   if (theta < -180) theta=theta+360
+  #   if (theta > 180) theta=theta-360
+  # #Upper right use a range that is between 90 and 450.
+  # } else if (fgang > 180){
+  #   while (theta <90) theta=theta+360
+  #   if (theta > 450) theta=theta-360
+  # # Lower right
+  # } else if (fgang >90 & fgang<180) {
+  #   while (theta <0) theta=theta+360
+  #   if (theta > 360) theta=theta-360
+  # #Lower left should be between -90 and 270
+  # } else {
+  #   if (theta < -90) theta=theta+360
+  #   if (theta > 270) theta=theta-360
+  # }
   return(theta)
 }
 
@@ -266,9 +278,9 @@ random_allocation <- function (nrandprobes=ngalprobes+6, nstdprobes=20, nguidepr
 #Draw buttons around each position to be allocated.
 draw_pos <- function(x,y, label_probe=TRUE, overwrite=TRUE){
   if (overwrite){ #set overwrite to true to start the plots from scratch.
-    aplot(0,0,pch='x',col="red",xlim=c(-fov/2.,fov/2.),ylim=c(-fov/2.,fov/2.), asp=1, xlab='X (mm)', ylab='Y (mm)')
+    aplot(0,0,pch='x',col="red",xlim=c(-fov/2.,fov/2.),ylim=c(-fov/2.,fov/2.), asp=1, xlab='X (deg)', ylab='Y (deg)')
     draw.circle(0,0,radius=fov/2.,border='red')
-    draw.circle(0,0,radius=fov/2.+skybuffer,border='black')
+    draw.circle(0,0,radius=1.,border='black')
     #Draw the cable exit gaps in cyan
     for (cceg in c(1:length(ceg_pos[,1]))){
       dx=wceg/2.* sind(ceg_pos[cceg,'deg'])
@@ -320,20 +332,19 @@ defineprobe <- function(xs,ys,angs,interactive=FALSE, col='black'){
   for (i in c(1:length(xs))) {
     x=xs[i]
     y=ys[i]
-    rbuff=2-cosd(delta_poly/2)#buffer to account for the approximation of small angles difference in radius.
-    #probe includes the whole exclusion area, so including the exclusion radius around the probe head.
-    probe=cbind(c(x+rbuff*excl_radius*sind(seq(-1.*atand(tip_l/tip_w)+delta_poly,180+atand(tip_l/tip_w)-delta_poly,delta_poly)), 
-                  x-tip_l/2.,
-                  x-tip_l/2.,
-                  x-tip_l/2.-probe_l, 
-                  x-tip_l/2.-probe_l, 
-                  x-tip_l/2.-probe_l-cable_l, 
-                  x-tip_l/2.-probe_l-cable_l, 
-                  x-tip_l/2.-probe_l, 
-                  x-tip_l/2.-probe_l, 
-                  x-tip_l/2., 
-                  x-tip_l/2.),
-                c(y-rbuff*excl_radius*cosd(seq(-1.*atand(tip_l/tip_w)+delta_poly,180+atand(tip_l/tip_w)-delta_poly,delta_poly)), 
+    probe=cbind(c(x+tip_w/2., 
+                  x-(tip_l-tip_w/2.),
+                  x-(tip_l-tip_w/2.),
+                  x-(tip_l-tip_w/2.)-probe_l, 
+                  x-(tip_l-tip_w/2.)-probe_l, 
+                  x-(tip_l-tip_w/2.)-probe_l-cable_l, 
+                  x-(tip_l-tip_w/2.)-probe_l-cable_l, 
+                  x-(tip_l-tip_w/2.)-probe_l, 
+                  x-(tip_l-tip_w/2.)-probe_l, 
+                  x-(tip_l-tip_w/2.), 
+                  x-(tip_l-tip_w/2.), 
+                  x+tip_w/2.),
+                c(y+tip_w/2., 
                   y+tip_w/2., 
                   y+probe_w/2., 
                   y+probe_w/2., 
@@ -343,26 +354,12 @@ defineprobe <- function(xs,ys,angs,interactive=FALSE, col='black'){
                   y-cable_w/2.,
                   y-probe_w/2., 
                   y-probe_w/2., 
+                  y-tip_w/2., 
                   y-tip_w/2.))
-    #footprint is just for display purposes when plotting, it is not used outside this function.
-    lpoly=length(probe[,1])
-    footprint=cbind(c(x+tip_w/2., 
-                      probe[(lpoly-9):lpoly,1], 
-                      x+tip_w/2.),
-                    c(y+tip_w/2., 
-                      probe[(lpoly-9):lpoly,2],
-                      y-tip_w/2.))
-    
-    #Rotating probe.
     probetemp=cbind(Rotate(probe,theta=angs[i], mx=x, my=y)$x, Rotate(probe,theta=angs[i], mx=x, my=y)$y)
     probe=probetemp
     colnames(probe)=c(paste('X',as.character(i), sep=''),paste('Y',as.character(i),sep=''))
-    
-    footprintemp=cbind(Rotate(footprint,theta=angs[i], mx=x, my=y)$x, Rotate(footprint,theta=angs[i], mx=x, my=y)$y)
-    footprint=footprintemp
-    colnames(footprint)=c(paste('X',as.character(i), sep=''),paste('Y',as.character(i),sep=''))
-    
-    if (interactive) {polygon(footprint, border=col)}#Drawing the actual shape of the probe, not the exclusion area.
+    if (interactive) {polygon(probe, border=col)}
     assign(paste('probe',as.character(i), sep=''), probe)
     probes=cbind(probes,probe)
   }
@@ -375,9 +372,7 @@ defineguideprobe <- function(gxs,gys,gangs,interactive=FALSE){
   for (i in c(1:length(gxs))) {
     x=gxs[i]
     y=gys[i]
-    rbuff=2-cosd(delta_poly/2)#buffer to account for the approximation of small angles difference in radius.
-    #gprobe includes the whole exclusion area, so including the exclusion radius around the probe head.
-    gprobe=cbind(c(x+rbuff*gexcl_radius*sind(seq(-1.*atand(gtip_l/gtip_w)+delta_poly,180+atand(gtip_l/gtip_w)-delta_poly,delta_poly)), 
+    gprobe=cbind(c(x+gtip_w/2., 
                    x-(gtip_l-gtip_w/2.),
                    x-(gtip_l-gtip_w/2.),
                    x-(gtip_l-gtip_w/2.)-gprobe_l, 
@@ -387,8 +382,9 @@ defineguideprobe <- function(gxs,gys,gangs,interactive=FALSE){
                    x-(gtip_l-gtip_w/2.)-gprobe_l, 
                    x-(gtip_l-gtip_w/2.)-gprobe_l, 
                    x-(gtip_l-gtip_w/2.), 
-                   x-(gtip_l-gtip_w/2.)),
-                 c(y-rbuff*gexcl_radius*cosd(seq(-1.*atand(gtip_l/gtip_w)+delta_poly,180+atand(gtip_l/gtip_w)-delta_poly, delta_poly)), 
+                   x-(gtip_l-gtip_w/2.), 
+                   x+gtip_w/2.),
+                 c(y+gtip_w/2., 
                    y+gtip_w/2., 
                    y+gprobe_w/2., 
                    y+gprobe_w/2., 
@@ -398,26 +394,12 @@ defineguideprobe <- function(gxs,gys,gangs,interactive=FALSE){
                    y-gcable_w/2.,
                    y-gprobe_w/2., 
                    y-gprobe_w/2., 
+                   y-gtip_w/2., 
                    y-gtip_w/2.))
-    
-    #footprint is just for display purposes when plotting, it is not used outside this function.
-    lpoly=length(gprobe[,1])
-    footprint=cbind(c(x+gtip_w/2., 
-                      gprobe[(lpoly-9):lpoly,1], 
-                      x+gtip_w/2.),
-                    c(y+gtip_w/2., 
-                      gprobe[(lpoly-9):lpoly,2],
-                      y-gtip_w/2.))
-    
-    #Rotating probe.
     gprobetemp=cbind(Rotate(gprobe,theta=gangs[i], mx=x, my=y)$x, Rotate(gprobe,theta=gangs[i], mx=x, my=y)$y)
     gprobe=gprobetemp
     colnames(gprobe)=c(paste('X',as.character(i), sep=''),paste('Y',as.character(i),sep=''))
-    footprintemp=cbind(Rotate(footprint,theta=gangs[i], mx=x, my=y)$x, Rotate(footprint,theta=gangs[i], mx=x, my=y)$y)
-    footprint=footprintemp
-    colnames(footprint)=c(paste('X',as.character(i), sep=''),paste('Y',as.character(i),sep=''))
-    
-    if (interactive) {polygon(footprint, border='darkgrey')} #Drawing the actual shape of the probe, not the exclusion area.
+    if (interactive) {polygon(gprobe, border='darkgrey')}
     assign(paste('gprobe',as.character(i), sep=''), gprobe)
     gprobes=cbind(gprobes,gprobe)
   }
@@ -430,15 +412,14 @@ find_probe_conflicts <- function(probes, pos, angs){
   if (dim(pos)[1] == 1) {
     return(probe_conflicts)
   }
-  lpoly=length(probes[,1]) #length of polygon defining probe.
   for (i in c(1:(length(pos[,'x'])-1))) {
-    p1 <- data.frame(PID=rep(i, lpoly), POS=(1:lpoly), X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')])
+    p1 <- data.frame(PID=rep(i, 12), POS=1:12, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')])
     for (j in c((i+1):length(pos[,'x']))) {
-      p2 <- data.frame(PID=rep(j, lpoly), POS=(1:lpoly), X=probes[,paste('X',as.character(j), sep='')], Y=probes[,paste('Y',as.character(j), sep='')])
+      p2 <- data.frame(PID=rep(j, 12), POS=1:12, X=probes[,paste('X',as.character(j), sep='')], Y=probes[,paste('Y',as.character(j), sep='')])
       if (!is.null(joinPolys(p1,p2))) {
         junction=joinPolys(p1,p2)
         #Compute the percentage area of a probe that overlaps.100% means they overlap perfectly. 0% means no overlap.
-        areapoly= round(polyarea(junction$X,junction$Y)/polyarea(p1$X,p1$Y) * 100, digits=1)
+        areapoly=round(polyarea(junction$X,junction$Y)/polyarea(p1$X,p1$Y) * 100, digits=1)
         probe_conflicts=rbind(probe_conflicts, c(i,j,areapoly))
       }
     }
@@ -453,30 +434,26 @@ find_probe_conflicts <- function(probes, pos, angs){
 #Looking for guide/target/standard conflicts with the target/standard probes fixed.
 find_guide_conflicts <- function(probes, pos, angs, gprobes, gpos, gangs){
   probe_conflicts=data.frame()
-  lpoly=length(probes[,1]) #length of polygon defining probe.
-  glpoly=length(gprobes[,1])
-  print("Identifying clashes with target and/or standard probes")
   #First identify clashes with target/standard probes:
   for (i in c(1:(length(pos[,'x'])))) {
-    p1 <- data.frame(PID=rep(i, lpoly), POS=(1:lpoly), X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')])
+    p1 <- data.frame(PID=rep(i, 12), POS=1:12, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')])
     for (j in 1:length(gpos[,'x'])) {
-      p2 <- data.frame(PID=rep(j, glpoly), POS=(1:glpoly), X=gprobes[,paste('X',as.character(j), sep='')], Y=gprobes[,paste('Y',as.character(j), sep='')])
+      p2 <- data.frame(PID=rep(j, 12), POS=1:12, X=gprobes[,paste('X',as.character(j), sep='')], Y=gprobes[,paste('Y',as.character(j), sep='')])
       if (!is.null(joinPolys(p1,p2))) {
         junction=joinPolys(p1,p2)
         #Compute the percentage area of a probe that overlaps.100% means they overlap perfectly. 0% means no overlap.
-        areapoly= round(polyarea(junction$X,junction$Y)/polyarea(p1$X,p1$Y) * 100, digits=1)
+        areapoly=round(polyarea(junction$X,junction$Y)/polyarea(p1$X,p1$Y) * 100, digits=1)
         probe_conflicts=rbind(probe_conflicts, c(i,j,areapoly))
       }
     }
   }
-  print('Identifying conflict with other guide probes.')
   #Now identify clashes between guide probes.
   if (length(gpos[,'x']) > 1) { #Only if there is more than one guide probe.
     for (i in c(1:(length(gpos[,'x'])))) {
-      p1 <- data.frame(PID=rep(i, lpoly), POS=(1:glpoly), X=gprobes[,paste('X',as.character(i), sep='')], Y=gprobes[,paste('Y',as.character(i), sep='')])
+      p1 <- data.frame(PID=rep(i, 12), POS=1:12, X=gprobes[,paste('X',as.character(i), sep='')], Y=gprobes[,paste('Y',as.character(i), sep='')])
       for (j in c(1:length(gpos[,'x']))) { 
         if (j!=i){
-          p2 <- data.frame(PID=rep(j, lpoly), POS=(1:glpoly), X=gprobes[,paste('X',as.character(j), sep='')], Y=gprobes[,paste('Y',as.character(j), sep='')])
+          p2 <- data.frame(PID=rep(j, 12), POS=1:12, X=gprobes[,paste('X',as.character(j), sep='')], Y=gprobes[,paste('Y',as.character(j), sep='')])
           if (!is.null(joinPolys(p1,p2))) {
             junction=joinPolys(p1,p2)
             #Compute the percentage area of a probe that overlaps.100% means they overlap perfectly. 0% means no overlap.
@@ -508,11 +485,15 @@ choose_cegs <- function(pos) {
   #y=pos[1,'y']
   #draw_pos(x=pos_master$pos[c(1:19),'x'],y=pos_master$pos[c(1:19),'y'])
   
+  #lines(x=c(x,mid_ceg_pos[2,'x']), y=c(y,mid_ceg_pos[2,'y']))
+  #lines(x=c(x,mid_ceg_pos[1,'x']), y=c(y,mid_ceg_pos[1,'y']))
+  #lines(x=c(x,mid_ceg_pos[3,'x']), y=c(y,mid_ceg_pos[3,'y']))
+  
   for (j in c(1:npos)){
     #Define area or "pizza slice" for each cable exit gap.
-    pizza1 = data.frame(PID=rep(1, 122), POS=1:122, X=c(pos[j,'x'],fov/2.*cosd(c(-30:-150))), Y=c(pos[j,'y'],fov/2.*sind(c(-30:-150))))
-    pizza2 = data.frame(PID=rep(2, 122), POS=1:122, X=c(pos[j,'x'],fov/2.*cosd(c(-30:90))), Y=c(pos[j,'y'],fov/2.*sind(c(-30:90))))
-    pizza3 = data.frame(PID=rep(3, 122), POS=1:122, X=c(pos[j,'x'],fov/2.*cosd(c(90:210))), Y=c(pos[j,'y'],fov/2.*sind(c(90:210))))
+    pizza1 = data.frame(PID=rep(1, 122), POS=1:122, X=c(pos[j,'x'],cosd(c(-30:-150))), Y=c(pos[j,'y'],sind(c(-30:-150))))
+    pizza2 = data.frame(PID=rep(2, 122), POS=1:122, X=c(pos[j,'x'],cosd(c(-30:90))), Y=c(pos[j,'y'],sind(c(-30:90))))
+    pizza3 = data.frame(PID=rep(3, 122), POS=1:122, X=c(pos[j,'x'],cosd(c(90:210))), Y=c(pos[j,'y'],sind(c(90:210))))
     nceg=c(-1,-1,-1) #Starting at -1 to avoid counting the probe itself.
     for (i in c(1:npos)){
       cx=pos[i,'x']
@@ -536,9 +517,9 @@ choose_cegs <- function(pos) {
       cegs[j]=which(min(nceg)==nceg)[which.min(pointDistance(p1=ceg_pos[which(min(nceg)==nceg),c('x','y')],p2=c(cx,cy), lonlat=FALSE))]
     }
     #If position is too close to the exit, move them to next closest exit.
-    E=pointDistance(p1=ceg_pos[cegs[j],c('x','y')], p2=pos[j,c('x','y')], lonlat=FALSE) - (probe_l+cable_l/3+tip_l/2.) ##E is the line joining the solid ferule end to the centre of the exit point.
+    E=pointDistance(p1=ceg_pos[cegs[j],c(‘x’,‘y’)], p2=pos[j,c(‘x’,‘y’)], lonlat=FALSE) - (probe_l+cable_l/3+tip_l/2.) ##E is the line joining the solid ferule end to the centre of the exit point.
     if (E < E0){ #E0 is the threshold to avoid blocking a cable exit gap. It is set above.
-      cegs[j]=order(pointDistance(p1=ceg_pos[,c('x','y')],p2=pos[j,c('x','y')], lonlat=FALSE))[2]
+      cegs[j]=order(pointDistance(p1=ceg_pos[,c(‘x’,‘y’)],p2=pos[j,c(‘x’,‘y’)], lonlat=FALSE))[2]
     }
   }
   return(cegs)
@@ -575,6 +556,9 @@ first_guess_angs <- function(pos, cegs, guide=FALSE){
     #}
   #}
   
+  #testing:
+  #draw_pos(x=pos[,'x'],y=pos[,'y'])
+  #defineprobe(xs=pos[,'x'],ys=pos[,'y'],angs=angs, interactive=T)
   return(angs)
 }
 
@@ -799,10 +783,9 @@ MinimizeGuideConflicts <- function(pos=pos, angs=angs, cegs=cegs, gpos=gpos, gan
 
 compute_total_conflict_area <- function(angs,pos=pos){
   probes=defineprobe(x=pos[,'x'],y=pos[,'y'],angs=angs, interactive=FALSE)
-  lpoly=length(probes[,1]) #length of polygon defining probe.
   sprobes=data.frame()
   for (i in c(1:(length(pos[,'x'])))) {
-    sprobes <- rbind(sprobes,cbind(PID=rep(i, lpoly), POS=1:lpoly, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')]))
+    sprobes <- rbind(sprobes,cbind(PID=rep(i, 12), POS=1:12, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')]))
   }
   sprobes=as.PolySet(sprobes)
   junction=joinPolys(sprobes,sprobes,operation='INT')
@@ -823,12 +806,11 @@ cleanconflictedstds <- function(angs,pos=pos, stdpos=pos_master$stdpos){
   draw_all(x=pos_master$pos[,'x'],y=pos_master$pos[,'y'],xs=stdpos[,'x'],ys=stdpos[,'y'],xg=pos_master$guidepos[,'x'],yg=pos_master$guidepos[,'y'], interactive=visualise)
   
   probes=defineprobe(x=pos[,'x'],y=pos[,'y'],angs=angs, interactive=visualise)
-  lpoly=length(probes[,1]) #length of polygon defining probe.
   
   #Setting up into sp objects that package rgeos will understand.
   sprobes=data.frame()
   for (i in c(1:ngalprobes)) {
-    sprobes <- rbind(sprobes,cbind(PID=rep(i, lpoly), POS=1:lpoly, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')]))
+    sprobes <- rbind(sprobes,cbind(PID=rep(i, 12), POS=1:12, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')]))
   }
   sprobes=as.PolySet(sprobes)
   for (j in c(1:ngalprobes)) {
@@ -852,12 +834,11 @@ cleanconflictedguides <- function(angs,pos=pos, guidepos=pos_master$guidepos){
   draw_all(x=pos_master$pos[,'x'],y=pos_master$pos[,'y'],xs=pos_master$stdpos[,'x'],ys=pos_master$stdpos[,'y'],xg=pos_master$guidepos[,'x'],yg=pos_master$guidepos[,'y'], interactive=visualise)
   
   probes=defineprobe(x=pos[,'x'],y=pos[,'y'],angs=angs, interactive=visualise)
-  lpoly=length(probes[,1]) #length of polygon defining probe.
   
   #Setting up into sp objects that package rgeos will understand.
   sprobes=data.frame()
   for (i in c(1:(ngalprobes+nstdprobes))) {
-    sprobes <- rbind(sprobes,cbind(PID=rep(i, lpoly), POS=1:lpoly, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')]))
+    sprobes <- rbind(sprobes,cbind(PID=rep(i, 12), POS=1:12, X=probes[,paste('X',as.character(i), sep='')], Y=probes[,paste('Y',as.character(i), sep='')]))
   }
   sprobes=as.PolySet(sprobes)
   for (j in c(1:(ngalprobes+nstdprobes))) {
@@ -1093,9 +1074,9 @@ configure_stdstars <- function(pos, angs, cegs, stdpos){
     nconflicts = dim(tempconflicts)[1]
     
     if (nconflicts > 0) {
-      #print(tempos)
+      print(tempos)
       #print(tempangs)
-      #print(tempconflicts)
+      print(tempconflicts)
       withTimeout(expr=assign('tempangs',MinimizeConflicts(pos=tempos, angs=tempangs, cegs=tempcegs, probe_conflicts=tempconflicts)), timeout=timeout, onTimeout='warning')
 
       draw_all(x=pos_master$pos[,'x'],y=pos_master$pos[,'y'],xs=clstdpos[,'x'],ys=clstdpos[,'y'],xg=pos_master$guidepos[,'x'],yg=pos_master$guidepos[,'y'], interactive=visualise)
